@@ -1,7 +1,8 @@
 #
-# Copyright (c) 2021 Airbyte, Inc., all rights reserved.
+# Copyright (c) 2023 Airbyte, Inc., all rights reserved.
 #
 
+import json
 import logging
 import logging.config
 import traceback
@@ -11,8 +12,6 @@ from airbyte_cdk.models import AirbyteLogMessage, AirbyteMessage
 from airbyte_cdk.utils.airbyte_secrets_utils import filter_secrets
 from deprecated import deprecated
 
-TRACE_LEVEL_NUM = 5
-
 LOGGING_CONFIG = {
     "version": 1,
     "disable_existing_loggers": False,
@@ -34,9 +33,8 @@ LOGGING_CONFIG = {
 
 def init_logger(name: str = None):
     """Initial set up of logger"""
-    logging.addLevelName(TRACE_LEVEL_NUM, "TRACE")
     logger = logging.getLogger(name)
-    logger.setLevel(TRACE_LEVEL_NUM)
+    logger.setLevel(logging.INFO)
     logging.config.dictConfig(LOGGING_CONFIG)
     return logger
 
@@ -51,16 +49,30 @@ class AirbyteLogFormatter(logging.Formatter):
         logging.WARNING: "WARN",
         logging.INFO: "INFO",
         logging.DEBUG: "DEBUG",
-        TRACE_LEVEL_NUM: "TRACE",
     }
 
     def format(self, record: logging.LogRecord) -> str:
         """Return a JSON representation of the log message"""
-        message = super().format(record)
         airbyte_level = self.level_mapping.get(record.levelno, "INFO")
-        message = filter_secrets(message)
-        log_message = AirbyteMessage(type="LOG", log=AirbyteLogMessage(level=airbyte_level, message=message))
-        return log_message.json(exclude_unset=True)
+        if airbyte_level == "DEBUG":
+            extras = self.extract_extra_args_from_record(record)
+            debug_dict = {"type": "DEBUG", "message": record.getMessage(), "data": extras}
+            return filter_secrets(json.dumps(debug_dict))
+        else:
+            message = super().format(record)
+            message = filter_secrets(message)
+            log_message = AirbyteMessage(type="LOG", log=AirbyteLogMessage(level=airbyte_level, message=message))
+            return log_message.json(exclude_unset=True)
+
+    @staticmethod
+    def extract_extra_args_from_record(record: logging.LogRecord):
+        """
+        The python logger conflates default args with extra args. We use an empty log record and set operations
+        to isolate fields passed to the log record via extra by the developer.
+        """
+        default_attrs = logging.LogRecord("", 0, "", 0, None, None, None).__dict__.keys()
+        extra_keys = set(record.__dict__.keys()) - default_attrs
+        return {k: str(getattr(record, k)) for k in extra_keys if hasattr(record, k)}
 
 
 def log_by_prefix(msg: str, default_level: str) -> Tuple[int, str]:
