@@ -172,6 +172,8 @@ spec:
         title: API Key
         description: Test API Key
         order: 0
+  advanced_auth:
+    auth_flow_type: "oauth2.0"
     """
     parsed_manifest = YamlDeclarativeSource._parse(content)
     resolved_manifest = resolver.preprocess_manifest(parsed_manifest)
@@ -257,6 +259,8 @@ spec:
         "description": "Test API Key",
         "order": 0,
     }
+    advanced_auth = spec.advanced_auth
+    assert advanced_auth.auth_flow_type.value == "oauth2.0"
 
 
 def test_interpolate_config():
